@@ -18,7 +18,7 @@ urlpatterns = [
     url(r'^robots\.txt$', robots),
     url(r'^test$', error_404),
     url(r'^sitemap\.xml$', sitemap),
-    url(r'^worker.js$', worker),
+    url(r'^worker(?P<version>.+).js$', worker),
     url(r'^admin_W3cJ32mq63V45CLvmjNbsqSJ32mq63V45CL/', admin.site.urls),
     url(r'^rosetta_WoQtYMRmgLV9iId6VEfAn1VxpH7aoOUeg/', include(rosetta_urls)),
     url(r'^wagtail_WSQtYMxmgLV9iIn6VE3An1VxpH9aoOUeg/', include(wagtailadmin_urls)),
